#ifndef OMIXER_H
#define OMIXER_H

// qt include

#include <qapp.h>
#include <qwidget.h>
#include <qframe.h>
#include <qpainter.h>
#include <qslider.h>
#include <stdlib.h>
#include <qpixmap.h>
#include <qpushbt.h>
#include <qpopmenu.h>
#include <qmenubar.h>
#include <qdialog.h>
#include <qlabel.h>
#include <qscrbar.h>
#include <qmsgbox.h>
#include <qfile.h>
#include <qtooltip.h>

// oss include

#include <sys/soundcard.h>
#include <sys/ioctl.h>

// device management include

#include <fcntl.h>

// consts

#define CHANNEL_SENSITIVITY    10
#define DEVICE_STEP            50

typedef struct SDeviceInfo
{
 int VolumeLeft;
 int VolumeRight;
 int Volume;
 int ChannelVal;
 bool Stereo;
 bool RecordSrc;
 bool Record;
 bool Muting;
 bool Init;
 bool Show;
};

typedef struct SMixerDevice
{
 int Handle;
 int DeviceMask;
 int RecMask;
 int StereoDeviceMask;
 int RecSrcMask;
 int Capabilities;
 bool ExclusiveInput;
};

class OVolumeSlider : public QSlider
{
 public:
  
  OVolumeSlider(QWidget* parent = 0, const char* name = 0);
  
  virtual void paintSlider (QPainter*, const QRect&);
};

/**************************************************************************
***  DeviceWidget                                                       ***
***  Volumeslider and Channelslider                                     ***
**************************************************************************/

class ODeviceWidget : public QFrame
{
 Q_OBJECT
 public:
 
  ODeviceWidget(int Devicename, int PicIndex, QWidget* parent=0, const char* name=0);
  ~ODeviceWidget();

  QPushButton* RecButton;

  void setVolume(int Volume);

 public slots:
 
  void recordChanged(bool State);

 signals:
 
  void toggleRecButtons();

 private:
 
  QFrame* DeviceFrame;
  OVolumeSlider* VolumeSlider;
  QScrollBar* ChannelSlider;

  QPushButton* MutingButton;

  int Devname;
  
 private slots:

  void mutingChanged();
  void volumeChanged(int Volume); 
  void channelChanged(int Value);
};


/**************************************************************************
***  Mixer Class
**************************************************************************/

class OMixer : public QFrame
{
 Q_OBJECT
 public:
 
  OMixer(const char* MixerDeviceName, QWidget* parent = 0, const char* name = 0);
  ~OMixer();

  void closeEvent( QCloseEvent* );
  
 private:
 
  bool findDevice(char Devicename);
  void initDevice(int Devicename, int PicIndex);
  void getVolume(int Devicename);
  void showDevices();

  bool findConfigurationFile();
  void saveConfiguration();
  void loadConfiguration();

  ODeviceWidget *DeviceWidget[SOUND_MIXER_NRDEVICES];  

  QPopupMenu *file;
  QPopupMenu *config;
  QPopupMenu *help;
  QMenuBar *menu;
  QFrame *Frame;

 private slots:
 
  void toggleRecButtons();
  void displayMixerInfo();
  void configDevices(int MenuIndex);
  void about();
  void exit();
};


#endif
